@@ -1,16 +1,16 @@
-use anyhow::Result;
 use clap::{App, AppSettings, Arg};
 use std::io::Write;
 use std::sync::Arc;
 use tokio::net::UdpSocket;
 use util::Conn;
 use webrtc_dtls::cipher_suite::CipherSuiteId;
+use webrtc_dtls::Error;
 use webrtc_dtls::{config::*, conn::DTLSConn};
 
 // cargo run --example dial_psk -- --server 127.0.0.1:4444
 
 #[tokio::main]
-async fn main() -> Result<()> {
+async fn main() -> Result<(), Error> {
     env_logger::Builder::new()
         .format(|buf, record| {
             writeln!(
@@ -60,7 +60,7 @@ async fn main() -> Result<()> {
     println!("connecting {}..", server);
 
     let config = Config {
-        psk: Some(Arc::new(|hint: &[u8]| -> Result<Vec<u8>> {
+        psk: Some(Arc::new(|hint: &[u8]| -> Result<Vec<u8>, Error> {
             println!("Server's hint: {}", String::from_utf8(hint.to_vec())?);
             Ok(vec![0xAB, 0xC1, 0x23])
         })),
