@@ -1,15 +1,15 @@
-use anyhow::Result;
 use clap::{App, AppSettings, Arg};
 use std::io::Write;
 use std::sync::Arc;
 use tokio::net::UdpSocket;
 use util::Conn;
+use webrtc_dtls::Error;
 use webrtc_dtls::{config::*, conn::DTLSConn, crypto::Certificate};
 
 // cargo run --example dial_selfsign -- --server 127.0.0.1:4444
 
 #[tokio::main]
-async fn main() -> Result<()> {
+async fn main() -> Result<(), Error> {
     env_logger::Builder::new()
         .format(|buf, record| {
             writeln!(
