@@ -3,8 +3,6 @@ use crate::client_certificate_type::ClientCertificateType;
 use crate::crypto::crypto_ccm::{CryptoCcm, CryptoCcmTagLen};
 use crate::prf::*;
 
-use anyhow::Result;
-
 #[derive(Clone)]
 pub struct CipherSuiteAes128Ccm {
     ccm: Option<CryptoCcm>,
@@ -102,10 +100,9 @@ impl CipherSuite for CipherSuiteAes128Ccm {
         if let Some(ccm) = &self.ccm {
             ccm.encrypt(pkt_rlh, raw)
         } else {
-            Err(
-                Error::new("CipherSuite has not been initialized, unable to encrypt".to_owned())
-                    .into(),
-            )
+            Err(Error::Other(
+                "CipherSuite has not been initialized, unable to encrypt".to_owned(),
+            ))
         }
     }
 
@@ -113,10 +110,9 @@ impl CipherSuite for CipherSuiteAes128Ccm {
         if let Some(ccm) = &self.ccm {
             ccm.decrypt(input)
         } else {
-            Err(
-                Error::new("CipherSuite has not been initialized, unable to decrypt".to_owned())
-                    .into(),
-            )
+            Err(Error::Other(
+                "CipherSuite has not been initialized, unable to decrypt".to_owned(),
+            ))
         }
     }
 }
