@@ -2,8 +2,6 @@ use super::*;
 use crate::crypto::crypto_gcm::*;
 use crate::prf::*;
 
-use anyhow::Result;
-
 #[derive(Clone)]
 pub struct CipherSuiteAes128GcmSha256 {
     gcm: Option<CryptoGcm>,
@@ -97,10 +95,9 @@ impl CipherSuite for CipherSuiteAes128GcmSha256 {
         if let Some(cg) = &self.gcm {
             cg.encrypt(pkt_rlh, raw)
         } else {
-            Err(
-                Error::new("CipherSuite has not been initialized, unable to encrypt".to_owned())
-                    .into(),
-            )
+            Err(Error::Other(
+                "CipherSuite has not been initialized, unable to encrypt".to_owned(),
+            ))
         }
     }
 
@@ -108,10 +105,9 @@ impl CipherSuite for CipherSuiteAes128GcmSha256 {
         if let Some(cg) = &self.gcm {
             cg.decrypt(input)
         } else {
-            Err(
-                Error::new("CipherSuite has not been initialized, unable to decrypt".to_owned())
-                    .into(),
-            )
+            Err(Error::Other(
+                "CipherSuite has not been initialized, unable to decrypt".to_owned(),
+            ))
         }
     }
 }
