@@ -1058,7 +1058,7 @@ impl DTLSConn {
                 return (
                     false,
                     Some(a),
-                    Some(Error::Other(format!("Error of Alert {}", a.to_string()))),
+                    Some(Error::Other(format!("Error of Alert {}", a))),
                 );
             }
             Content::ChangeCipherSpec(_) => {
