@@ -6,7 +6,7 @@ use std::io::{BufReader, BufWriter};
 use std::time::{Duration, SystemTime};
 
 #[test]
-fn test_handshake_message_client_hello() -> Result<(), Error> {
+fn test_handshake_message_client_hello() -> Result<()> {
     let raw_client_hello = vec![
         0xfe, 0xfd, 0xb6, 0x2f, 0xce, 0x5c, 0x42, 0x54, 0xff, 0x86, 0xe1, 0x24, 0x41, 0x91, 0x42,
         0x62, 0x15, 0xad, 0x16, 0xc9, 0x15, 0x8d, 0x95, 0x71, 0x8a, 0xbb, 0x22, 0xd7, 0x47, 0xec,
