@@ -2,7 +2,7 @@ use super::*;
 use crate::cipher_suite::CipherSuiteHash;
 
 #[test]
-fn test_pre_master_secret() -> Result<(), Error> {
+fn test_pre_master_secret() -> Result<()> {
     let private_key: [u8; 32] = [
         0x20, 0x21, 0x22, 0x23, 0x24, 0x25, 0x26, 0x27, 0x28, 0x29, 0x2a, 0x2b, 0x2c, 0x2d, 0x2e,
         0x2f, 0x30, 0x31, 0x32, 0x33, 0x34, 0x35, 0x36, 0x37, 0x38, 0x39, 0x3a, 0x3b, 0x3c, 0x3d,
@@ -34,7 +34,7 @@ fn test_pre_master_secret() -> Result<(), Error> {
 }
 
 #[test]
-fn test_master_secret() -> Result<(), Error> {
+fn test_master_secret() -> Result<()> {
     let pre_master_secret = vec![
         0xdf, 0x4a, 0x29, 0x1b, 0xaa, 0x1e, 0xb7, 0xcf, 0xa6, 0x93, 0x4b, 0x29, 0xb4, 0x74, 0xba,
         0xad, 0x26, 0x97, 0xe2, 0x9f, 0x1f, 0x92, 0x0d, 0xcc, 0x77, 0xc8, 0xa0, 0xa0, 0x88, 0x44,
@@ -74,7 +74,7 @@ fn test_master_secret() -> Result<(), Error> {
 }
 
 #[test]
-fn test_encryption_keys() -> Result<(), Error> {
+fn test_encryption_keys() -> Result<()> {
     let client_random = vec![
         0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08, 0x09, 0x0a, 0x0b, 0x0c, 0x0d, 0x0e,
         0x0f, 0x10, 0x11, 0x12, 0x13, 0x14, 0x15, 0x16, 0x17, 0x18, 0x19, 0x1a, 0x1b, 0x1c, 0x1d,
@@ -128,7 +128,7 @@ fn test_encryption_keys() -> Result<(), Error> {
 }
 
 #[test]
-fn test_verify_data() -> Result<(), Error> {
+fn test_verify_data() -> Result<()> {
     let client_hello = vec![
         0x01, 0x00, 0x00, 0xa1, 0x03, 0x03, 0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08,
         0x09, 0x0a, 0x0b, 0x0c, 0x0d, 0x0e, 0x0f, 0x10, 0x11, 0x12, 0x13, 0x14, 0x15, 0x16, 0x17,
